# encoding: utf-8
"""
@project: djangoModel->service_register
@author: 孙楷炎
@Email: sky4834@163.com
@synopsis: 对外开放服务调用注册白名单
@created_time: 2023/1/12 14:29
"""
from jsonrpc import jsonrpc_method

import xj_common
from xj_common.utils.service_manager import ServiceManager
from .services import notice_services


# ============= section 微服务测试放啊 start =========================
@jsonrpc_method("hello_rpc")
def hello_rpc(*args, **kwargs):
    return {"msg": "Hi rpc!!!"}


def hello(*args, name="word", **kwargs):
    print(args, kwargs)
    return {"msg": "Hi " + str(name) + "!!!"}


# ============= section 微服务测试放啊 end =========================

# 对外服务白名单
register_list = [
    {
        "service_name": "hello",
        "pointer": hello
    },
    {
        "service_name": "notice_add",
        "pointer": notice_services.NoticeServices.notice_add
    },
    {
        "service_name": "notice_edit",
        "pointer": notice_services.NoticeServices.notice_edit
    },
]

server_manager = ServiceManager()


# 遍历注册
def register():
    for i in register_list:
        setattr(xj_common, i["service_name"], i["pointer"])
        server_manager.put_service(route=i["service_name"], method=i["pointer"])


if __name__ == '__main__':
    register()



from django.urls import re_path

from xj_common.apis import notice_apis, region_api, translate_apis, access_level_apis, service_manage_api, encyclopedia_api
from .service_register import register

register()
urlpatterns = [
    # 地区相关API
    re_path(r'^region_list/?$', region_api.RegionAPIS.region_list, ),
    re_path(r'^region_tree/?$', region_api.RegionAPIS.get_region_tree, ),
    re_path(r'^region_add/?$', region_api.RegionAPIS.region_add, ),
    re_path(r'^region_edit/?$', region_api.RegionAPIS.region_edit, ),
    re_path(r'^region_del/?$', region_api.RegionAPIS.region_del, ),

    # 公共翻译
    re_path(r'^translate_article/?$', translate_apis.TranslateApis.translate_article, ),
    re_path(r'^translate_test/?$', translate_apis.TranslateApis.as_view(), ),

    # 提醒相关接口
    re_path(r'^notice_add/?$', notice_apis.NoticeApis.notice_add),
    re_path(r'^notice_edit/?$', notice_apis.NoticeApis.notice_edit),
    re_path(r'^notice_list/?$', notice_apis.NoticeApis.notice_list),
    re_path(r'^notice_type_list/?$', notice_apis.NoticeApis.type_list),

    # 访问级别
    re_path(r'^access_level_list/?$', access_level_apis.AccessLevelAPIView.access_level_list),

    # 服务治理
    re_path(r'^find_service_test/?$', service_manage_api.ServiceManageApis.find_service_test),  # 发现服务
    re_path(r'^ask_question/?$', encyclopedia_api.EncyclopediaApis.ask_question),  # 发现服务
]
